asr.test.test\_recipes
======================

.. automodule:: asr.test.test_recipes

   
   
   .. rubric:: Functions

   
   .. autofunction:: test_recipe_cli_help_calls
   .. autofunction:: test_recipe_cli_types
   .. autofunction:: test_recipe_type_hints
   .. autofunction:: test_recipe_use_new_webpanel_implementation
   
   

   
   
   

   
   
   